@@ -22,7 +22,6 @@ class QPushButton;
 
 namespace Kleo
 {
-class EMailOperationsPreferences;
 class FileOperationsPreferences;
 class Settings;
 
@@ -49,13 +48,10 @@ private:
     void setupProfileGui(QBoxLayout *layout);
     void applyProfile(const QString &profile);
 
-    void load(const Kleo::EMailOperationsPreferences &emailPrefs,
-              const Kleo::FileOperationsPreferences &filePrefs,
+    void load(const Kleo::FileOperationsPreferences &filePrefs,
               const Kleo::Settings &settings);
 
 private:
-    QCheckBox *mQuickEncryptCB = nullptr;
-    QCheckBox *mQuickSignCB = nullptr;
     QCheckBox *mPGPFileExtCB = nullptr;
     QCheckBox *mAutoDecryptVerifyCB = nullptr;
     QCheckBox *mAutoExtractArchivesCB = nullptr;
