@@ -35,6 +35,10 @@
 #include <KLocalizedString>
 #include "kleopatra_debug.h"
 
+#if QGPGME_SUPPORTS_ARCHIVE_JOBS
+#include <QGpgME/SignEncryptArchiveJob>
+#endif
+
 #include <QPointer>
 #include <QTimer>
 #include <QFileInfo>
@@ -241,15 +245,16 @@ static const char *extension(bool pgp, bool sign, bool encrypt, bool ascii, bool
 
 static std::shared_ptr<ArchiveDefinition> getDefaultAd()
 {
-    std::vector<std::shared_ptr<ArchiveDefinition> > ads = ArchiveDefinition::getArchiveDefinitions();
+    const std::vector<std::shared_ptr<ArchiveDefinition>> ads = ArchiveDefinition::getArchiveDefinitions();
     Q_ASSERT(!ads.empty());
     std::shared_ptr<ArchiveDefinition> ad = ads.front();
     const FileOperationsPreferences prefs;
-    Q_FOREACH (const std::shared_ptr<ArchiveDefinition> toCheck, ads) {
-        if (toCheck->id() == prefs.archiveCommand()) {
-            ad = toCheck;
-            break;
-        }
+    const QString archiveCmd = prefs.archiveCommand();
+    auto it = std::find_if(ads.cbegin(), ads.cend(), [&archiveCmd](const std::shared_ptr<ArchiveDefinition> &toCheck) {
+        return toCheck->id() == archiveCmd;
+    });
+    if (it != ads.cend()) {
+        ad = *it;
     }
     return ad;
 }
@@ -310,17 +315,38 @@ static QMap <int, QString> buildOutputNamesForDir(const QString &file, const QMa
     return ret;
 }
 
+// strips all trailing slashes from the filename, but keeps filename "/"
+static QString stripTrailingSlashes(const QString &fileName)
+{
+    if (fileName.size() < 2 || !fileName.endsWith(QLatin1Char('/'))) {
+        return fileName;
+    }
+    auto tmp = QStringView{fileName}.chopped(1);
+    while (tmp.size() > 1 && tmp.endsWith(QLatin1Char('/'))) {
+        tmp.chop(1);
+    }
+    return tmp.toString();
+}
+
+static QStringList stripTrailingSlashesForAll(const QStringList &fileNames)
+{
+    QStringList result;
+    result.reserve(fileNames.size());
+    std::transform(fileNames.begin(), fileNames.end(), std::back_inserter(result), &stripTrailingSlashes);
+    return result;
+}
+
 void SignEncryptFilesController::setFiles(const QStringList &files)
 {
     kleo_assert(!files.empty());
-    d->files = files;
+    d->files = stripTrailingSlashesForAll(files);
     bool archive = false;
 
-    if (files.size() > 1) {
+    if (d->files.size() > 1) {
         setOperationMode((operationMode() & ~ArchiveMask) | ArchiveAllowed);
         archive = true;
     }
-    for (const auto &file: files) {
+    for (const auto &file: d->files) {
         if (QFileInfo(file).isDir()) {
             setOperationMode((operationMode() & ~ArchiveMask) | ArchiveForced);
             archive = true;
@@ -329,7 +355,7 @@ void SignEncryptFilesController::setFiles(const QStringList &files)
     }
     d->ensureWizardCreated();
     d->wizard->setSingleFile(!archive);
-    d->wizard->setOutputNames(buildOutputNames(files, archive));
+    d->wizard->setOutputNames(buildOutputNames(d->files, archive));
 }
 
 void SignEncryptFilesController::Private::slotWizardCanceled()
@@ -375,6 +401,15 @@ createSignEncryptTaskForFileInfo(const QFileInfo &fi, bool ascii,
     return task;
 }
 
+static bool archiveJobsCanBeUsed([[maybe_unused]] GpgME::Protocol protocol)
+{
+#if QGPGME_SUPPORTS_ARCHIVE_JOBS
+    return (protocol == GpgME::OpenPGP) && QGpgME::SignEncryptArchiveJob::isSupported();
+#else
+    return false;
+#endif
+}
+
 static std::shared_ptr<SignEncryptTask>
 createArchiveSignEncryptTaskForFiles(const QStringList &files,
                                      const std::shared_ptr<ArchiveDefinition> &ad, bool pgp, bool ascii,
@@ -382,6 +417,7 @@ createArchiveSignEncryptTaskForFiles(const QStringList &files,
                                      const QString& outputName, bool symmetric)
 {
     const std::shared_ptr<SignEncryptTask> task(new SignEncryptTask);
+    task->setCreateArchive(true);
     task->setEncryptSymmetric(symmetric);
     Q_ASSERT(!signers.empty() || !recipients.empty() || symmetric);
     task->setAsciiArmor(ascii);
@@ -399,12 +435,14 @@ createArchiveSignEncryptTaskForFiles(const QStringList &files,
         task->setEncrypt(false);
     }
 
-    kleo_assert(ad);
-
     const Protocol proto = pgp ? OpenPGP : CMS;
 
     task->setInputFileNames(files);
-    task->setInput(ad->createInputFromPackCommand(proto, files));
+    if (!archiveJobsCanBeUsed(proto)) {
+        // use legacy archive creation
+        kleo_assert(ad);
+        task->setInput(ad->createInputFromPackCommand(proto, files));
+    }
 
     task->setOutputFileName(outputName);
 
@@ -514,7 +552,7 @@ void SignEncryptFilesController::Private::slotWizardOperationPrepared()
         const bool ascii = prefs.addASCIIArmor();
 
         std::vector<Key> pgpRecipients, cmsRecipients, pgpSigners, cmsSigners;
-        Q_FOREACH (const Key &k, recipients) {
+        for (const Key &k : recipients) {
             if (k.protocol() == GpgME::OpenPGP) {
                 pgpRecipients.push_back(k);
             } else {
@@ -522,7 +560,7 @@ void SignEncryptFilesController::Private::slotWizardOperationPrepared()
             }
         }
 
-        Q_FOREACH (const Key &k, signers) {
+        for (const Key &k : signers) {
             if (k.protocol() == GpgME::OpenPGP) {
                 pgpSigners.push_back(k);
             } else {
@@ -547,7 +585,7 @@ void SignEncryptFilesController::Private::slotWizardOperationPrepared()
                     wizard->encryptSymmetric());
 
         } else {
-            Q_FOREACH (const QString &file, files) {
+            for (const QString &file : std::as_const(files)) {
                 const std::vector< std::shared_ptr<SignEncryptTask> > created =
                     createSignEncryptTasksForFileInfo(QFileInfo(file), ascii,
                             pgpRecipients,
@@ -561,7 +599,7 @@ void SignEncryptFilesController::Private::slotWizardOperationPrepared()
         }
 
         const std::shared_ptr<OverwritePolicy> overwritePolicy(new OverwritePolicy(wizard));
-        Q_FOREACH (const std::shared_ptr<SignEncryptTask> &i, tasks) {
+        for (const std::shared_ptr<SignEncryptTask> &i : tasks) {
             i->setOverwritePolicy(overwritePolicy);
         }
 
