@@ -52,7 +52,6 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KSeparator>
-#include <kwidgetsaddons_version.h>
 
 #include <gpgme++/context.h>
 #include <gpgme++/key.h>
@@ -356,7 +355,7 @@ private:
                 buttonRow->addWidget(trustChainDetailsBtn);
 
                 refreshBtn = new QPushButton{i18nc("@action:button", "Update"), parent};
-#ifndef QGPGME_SUPPORTS_KEY_REFRESH
+#if !QGPGME_SUPPORTS_KEY_REFRESH
                 refreshBtn->setVisible(false);
 #endif
                 buttonRow->addWidget(refreshBtn);
@@ -441,7 +440,7 @@ void CertificateDetailsWidget::Private::setupCommonProperties()
     // update visibility of UI elements
     ui.userIDs->setVisible(isOpenPGP);
     ui.addUserIDBtn->setVisible(isOwnKey);
-#ifdef QGPGME_SUPPORTS_SET_PRIMARY_UID
+#if QGPGME_SUPPORTS_SET_PRIMARY_UID
     ui.setPrimaryUserIDBtn->setVisible(isOwnKey);
 #else
     ui.setPrimaryUserIDBtn->setVisible(false);
@@ -627,11 +626,7 @@ void CertificateDetailsWidget::Private::revokeUserID(const GpgME::UserID &userId
     auto confirmButton = KStandardGuiItem::ok();
     confirmButton.setText(i18nc("@action:button", "Revoke User ID"));
     confirmButton.setToolTip({});
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     const auto choice = KMessageBox::questionTwoActions(
-#else
-    const auto choice = KMessageBox::questionYesNo(
-#endif
         q->window(),
         message,
         i18nc("@title:window", "Confirm Revocation"),
@@ -639,11 +634,7 @@ void CertificateDetailsWidget::Private::revokeUserID(const GpgME::UserID &userId
         KStandardGuiItem::cancel(),
         {},
         KMessageBox::Notify | KMessageBox::WindowModal);
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (choice != KMessageBox::ButtonCode::PrimaryAction) {
-#else
-    if (choice != KMessageBox::Yes) {
-#endif
         return;
     }
 
@@ -818,7 +809,7 @@ void CertificateDetailsWidget::Private::userIDTableContextMenuRequested(const QP
 {
     const auto userIDs = selectedUserIDs(ui.userIDTable);
     const auto singleUserID = (userIDs.size() == 1) ? userIDs.front() : GpgME::UserID{};
-#ifdef QGPGME_SUPPORTS_SET_PRIMARY_UID
+#if QGPGME_SUPPORTS_SET_PRIMARY_UID
     const bool isPrimaryUserID = !singleUserID.isNull() && (ui.userIDTable->selectedItems().front() == ui.userIDTable->topLevelItem(0));
 #endif
     const bool canSignUserIDs = userHasCertificationKey();
@@ -826,7 +817,7 @@ void CertificateDetailsWidget::Private::userIDTableContextMenuRequested(const QP
     const auto keyCanBeCertified = Kleo::canBeCertified(key);
 
     auto menu = new QMenu(q);
-#ifdef QGPGME_SUPPORTS_SET_PRIMARY_UID
+#if QGPGME_SUPPORTS_SET_PRIMARY_UID
     if (key.hasSecret()) {
         auto action = menu->addAction(QIcon::fromTheme(QStringLiteral("favorite")),
                                       i18nc("@action:inmenu", "Flag as Primary User ID"),
@@ -893,9 +884,10 @@ void CertificateDetailsWidget::Private::showMoreDetails()
         cmd->setUseDialog(true);
         cmd->start();
     } else {
-        QScopedPointer<SubKeysDialog> dlg(new SubKeysDialog(q));
+        auto dlg = new SubKeysDialog{q};
+        dlg->setAttribute(Qt::WA_DeleteOnClose);
         dlg->setKey(key);
-        dlg->exec();
+        dlg->open();
     }
 }
 
